# AgentsAegis Training Package

This is a **safe, empty package** used by [AgentsAegis](https://agentsaegis.com) for security awareness training.

It contains no executable code. If you installed this, your AI coding assistant suggested it as part of a security training exercise.

Learn more at [agentsaegis.com](https://agentsaegis.com)
